@@ -283,17 +283,17 @@ static const int month_days[] = {
 static int
 days_of_month(int y, int m)
 {
-	int	days;
+	int	ndays;
 
 	if (m < 0 || 12 < m)
 		ereport(ERROR,
 				(errcode(ERRCODE_DATETIME_VALUE_OUT_OF_RANGE),
 				 errmsg("date out of range")));
 
-	days = month_days[m - 1];
+	ndays = month_days[m - 1];
 	if (m == 2 && (y % 400 == 0 || (y % 4 == 0 && y % 100 != 0)))
-		days += 1;	/* February 29 in leap year */
-	return days;
+		ndays += 1;	/* February 29 in leap year */
+	return ndays;
 }
 
 /********************************************************************
@@ -356,13 +356,13 @@ add_months(PG_FUNCTION_ARGS)
 	DateADT day = PG_GETARG_DATEADT(0);
 	int n = PG_GETARG_INT32(1);
 	int y, m, d;
-	int	days;
+	int	ndays;
 	DateADT result;
 	div_t	v;
-	bool	last_day;
+	bool	is_last_day;
 
 	j2date(day + POSTGRES_EPOCH_JDATE, &y, &m, &d);
-	last_day = (d == days_of_month(y, m));
+	is_last_day = (d == days_of_month(y, m));
 
 	v = div(y * 12 + m - 1 + n, 12);
 	y = v.quot;
@@ -370,9 +370,9 @@ add_months(PG_FUNCTION_ARGS)
 		y += 1;	/* offset because of year 0 */
 	m = v.rem + 1;
 
-	days = days_of_month(y, m);
-	if (last_day || d > days)
-		d = days;
+	ndays = days_of_month(y, m);
+	if (is_last_day || d > ndays)
+		d = ndays;
 
 	result = date2j(y, m, d) - POSTGRES_EPOCH_JDATE;
 
@@ -391,8 +391,8 @@ add_months(PG_FUNCTION_ARGS)
 static DateADT
 iso_year (int y, int m, int d)
 {
-	DateADT result, result2, day;
-	int off;
+	DateADT		result, day;
+	int			off;
 
 	result = DATE2J(y,1,1);
 	day = DATE2J(y,m,d);
@@ -408,12 +408,14 @@ iso_year (int y, int m, int d)
 
 	if (((day - result) / 7 + 1) > 52)
 	{
-	result2 = DATE2J(y+1,1,1);
-	off = 4 - J2DAY(result2);
-	result2 += off + ((off >= 0) ? - 3: + 4);  /* to monday */
+		DateADT		result2;
 
-	if (day >= result2)
-		return result2;
+		result2 = DATE2J(y+1,1,1);
+		off = 4 - J2DAY(result2);
+		result2 += off + ((off >= 0) ? - 3: + 4);  /* to monday */
+
+		if (day >= result2)
+			return result2;
 	}
 
 	return result;
