@@ -1,8 +1,28 @@
 #include "postgres.h"
 #include <stdlib.h>
 #include <locale.h>
+
+#if PG_VERSION_NUM < 160000
+
+#include "access/genam.h"
+#include "access/heapam.h"
+#include "access/htup_details.h"
+#include "access/sysattr.h"
+
+#if PG_VERSION_NUM >= 120000
+
+#include "access/table.h"
+
+#endif
+
+#endif
+
+#include "catalog/indexing.h"
+#include "catalog/pg_extension.h"
 #include "catalog/pg_operator.h"
+#include "catalog/pg_proc.h"
 #include "catalog/pg_type.h"
+#include "commands/extension.h"
 #include "fmgr.h"
 #include "lib/stringinfo.h"
 #include "nodes/nodeFuncs.h"
@@ -10,14 +30,19 @@
 #include "nodes/primnodes.h"
 #include "parser/parse_expr.h"
 #include "parser/parse_oper.h"
+#include "storage/lock.h"
+#include "storage/proc.h"
 #include "utils/array.h"
 #include "utils/arrayaccess.h"
 #include "utils/builtins.h"
+#include "utils/catcache.h"
 #include "utils/datum.h"
+#include "utils/fmgroids.h"
 #include "utils/lsyscache.h"
 #include "utils/memutils.h"
 #include "utils/syscache.h"
 #include "utils/typcache.h"
+#include "utils/uuid.h"
 #include "orafce.h"
 #include "builtins.h"
 
@@ -31,8 +56,157 @@ static size_t multiplication = 1;
 
 text *def_locale = NULL;
 
+char *orafce_sys_guid_source;
+
+static Oid uuid_generate_func_oid = InvalidOid;
+static FmgrInfo uuid_generate_func_finfo;
+
+/* The oid of function should be valid in oene transaction */
+static LocalTransactionId uuid_generate_func_lxid = InvalidLocalTransactionId;
+static char uuid_generate_func_name[30] = "";
+
 static Datum ora_greatest_least(FunctionCallInfo fcinfo, bool greater);
 
+#if PG_VERSION_NUM < 160000
+
+static Oid
+get_extension_schema(Oid ext_oid)
+{
+	Oid			result;
+	Relation	rel;
+	SysScanDesc scandesc;
+	HeapTuple	tuple;
+	ScanKeyData entry[1];
+
+#if PG_VERSION_NUM >= 120000
+
+	rel = table_open(ExtensionRelationId, AccessShareLock);
+
+	ScanKeyInit(&entry[0],
+				Anum_pg_extension_oid,
+				BTEqualStrategyNumber, F_OIDEQ,
+				ObjectIdGetDatum(ext_oid));
+
+#else
+
+	rel = heap_open(ExtensionRelationId, AccessShareLock);
+
+	ScanKeyInit(&entry[0],
+				ObjectIdAttributeNumber,
+				BTEqualStrategyNumber, F_OIDEQ,
+				ObjectIdGetDatum(ext_oid));
+
+#endif
+
+	scandesc = systable_beginscan(rel, ExtensionOidIndexId, true,
+								  NULL, 1, entry);
+
+	tuple = systable_getnext(scandesc);
+
+	/* We assume that there can be at most one matching tuple */
+	if (HeapTupleIsValid(tuple))
+		result = ((Form_pg_extension) GETSTRUCT(tuple))->extnamespace;
+	else
+		result = InvalidOid;
+
+	systable_endscan(scandesc);
+
+#if PG_VERSION_NUM >= 120000
+
+	table_close(rel, AccessShareLock);
+
+#else
+
+	heap_close(rel, AccessShareLock);
+
+#endif
+
+	return result;
+}
+
+#endif
+
+static Oid
+get_uuid_generate_func_oid(bool *reset_fmgr)
+{
+	Oid			result = InvalidOid;
+
+	if (uuid_generate_func_lxid != MyProc->lxid ||
+		uuid_generate_func_oid == InvalidOid ||
+		strcmp(orafce_sys_guid_source, uuid_generate_func_name) != 0)
+	{
+		if (strcmp(orafce_sys_guid_source, "gen_random_uuid") == 0)
+		{
+			/* generated uuid can have not nice features, but uses buildin functionality */
+			result = fmgr_internal_function("gen_random_uuid");
+		}
+		else
+		{
+			Oid uuid_ossp_oid = InvalidOid;
+			Oid uuid_ossp_namespace_oid = InvalidOid;
+			CatCList   *catlist;
+			int			i;
+
+			uuid_ossp_oid = get_extension_oid("uuid-ossp", true);
+			if (!OidIsValid(uuid_ossp_oid))
+				ereport(ERROR,
+						(errcode(ERRCODE_UNDEFINED_OBJECT),
+						 errmsg("extension \"uuid-ossp\" is not installed"),
+						 errhint("the extension \"uuid-ossp\" should be installed before using \"sys_guid\" function")));
+
+			uuid_ossp_namespace_oid = get_extension_schema(uuid_ossp_oid);
+			Assert(OidIsValid(uuid_ossp_namespace_oid));
+
+			/* Search syscache by name only */
+			catlist = SearchSysCacheList1(PROCNAMEARGSNSP,
+										  CStringGetDatum(orafce_sys_guid_source));
+
+			for (i = 0; i < catlist->n_members; i++)
+			{
+				HeapTuple	proctup = &catlist->members[i]->tuple;
+				Form_pg_proc procform = (Form_pg_proc) GETSTRUCT(proctup);
+
+				/*
+				 * Consider only procs in specified namespace,
+				 * with zero arguments and uuid type as result
+				 */
+				if (procform->pronamespace != uuid_ossp_namespace_oid ||
+					 procform->pronargs != 0 || procform->prorettype != UUIDOID)
+					continue;
+
+#if PG_VERSION_NUM >= 120000
+
+				result = procform->oid;
+
+#else
+
+				result = HeapTupleGetOid(proctup);
+
+#endif
+
+				break;
+			}
+
+			ReleaseSysCacheList(catlist);
+		}
+
+		/* should be available if extension uuid-ossp is installed */
+		if (!OidIsValid(result))
+			elog(ERROR, "function \"%s\" doesn't exist", orafce_sys_guid_source);
+
+		uuid_generate_func_lxid = MyProc->lxid;
+		uuid_generate_func_oid = result;
+		strcpy(uuid_generate_func_name, orafce_sys_guid_source);
+		*reset_fmgr = true;
+	}
+	else
+		*reset_fmgr = false;
+
+	Assert(OidIsValid(uuid_generate_func_oid));
+
+	return uuid_generate_func_oid;
+}
+
 PG_FUNCTION_INFO_V1(ora_lnnvl);
 
 Datum
@@ -133,17 +307,13 @@ ora_set_nls_sort(PG_FUNCTION_ARGS)
 static text*
 _nls_run_strxfrm(text *string, text *locale)
 {
-	char *string_str;
-	int string_len;
-
-	char *locale_str = NULL;
-	int locale_len = 0;
-
-	text *result;
-	char *tmp = NULL;
-	size_t size = 0;
-	size_t rest = 0;
-	int changed_locale = 0;
+	char	   *string_str;
+	int			string_len;
+	char	   *locale_str = NULL;
+	text		*result;
+	char	   *tmp = NULL;
+	size_t		rest = 0;
+	bool		changed_locale = false;
 
 	/*
 	 * Save the default, server-wide locale setting.
@@ -176,29 +346,29 @@ _nls_run_strxfrm(text *string, text *locale)
 
 	if (locale)
 	{
-		locale_len = VARSIZE_ANY_EXHDR(locale);
-	}
-
-	/*
-	 * If different than default locale is requested, call setlocale.
-	 */
-	if (locale_len > 0
-		&& (strncmp(lc_collate_cache, VARDATA_ANY(locale), locale_len)
-			|| *(lc_collate_cache + locale_len) != '\0'))
-	{
-		locale_str = palloc(locale_len + 1);
-		memcpy(locale_str, VARDATA_ANY(locale), locale_len);
-		*(locale_str + locale_len) = '\0';
+		int			locale_len = VARSIZE_ANY_EXHDR(locale);
 
 		/*
-		 * Try to set correct locales.
-		 * If setlocale failed, we know the default stayed the same,
-		 * co we can safely elog.
+		 * If different than default locale is requested, call setlocale.
 		 */
-		if (!setlocale(LC_COLLATE, locale_str))
-			elog(ERROR, "failed to set the requested LC_COLLATE value [%s]", locale_str);
+		if (locale_len > 0
+			&& (strncmp(lc_collate_cache, VARDATA_ANY(locale), locale_len)
+				|| *(lc_collate_cache + locale_len) != '\0'))
+		{
+			locale_str = palloc(locale_len + 1);
+			memcpy(locale_str, VARDATA_ANY(locale), locale_len);
+			*(locale_str + locale_len) = '\0';
 
-		changed_locale = 1;
+			/*
+			 * Try to set correct locales.
+			 * If setlocale failed, we know the default stayed the same,
+			 * co we can safely elog.
+			 */
+			if (!setlocale(LC_COLLATE, locale_str))
+				elog(ERROR, "failed to set the requested LC_COLLATE value [%s]", locale_str);
+
+			changed_locale = true;
+		}
 	}
 
 	/*
@@ -209,6 +379,7 @@ _nls_run_strxfrm(text *string, text *locale)
 	 */
 	PG_TRY();
 	{
+		size_t		size = 0;
 
 		/*
 		 * Text transformation.
@@ -669,3 +840,62 @@ ora_greatest_least(FunctionCallInfo fcinfo, bool greater)
 
 	PG_RETURN_DATUM(result);
 }
+
+#if PG_VERSION_NUM < 120000
+
+static Datum
+FunctionCall0Coll(FmgrInfo *flinfo, Oid collation)
+{
+	FunctionCallInfoData fcinfo_data;
+	FunctionCallInfo fcinfo = &fcinfo_data;
+	Datum		result;
+
+	InitFunctionCallInfoData(*fcinfo, flinfo, 0, collation, NULL, NULL);
+
+	result = FunctionCallInvoke(fcinfo);
+
+	/* Check for null result, since caller is clearly not expecting one */
+	if (fcinfo->isnull)
+		elog(ERROR, "function %u returned NULL", flinfo->fn_oid);
+
+	return result;
+}
+
+#endif
+
+
+PG_FUNCTION_INFO_V1(orafce_sys_guid);
+
+/*
+ * Implementation of sys_guid() function
+ *
+ * Oracle uses guid based on mac address. The calculation is not too
+ * difficult, but there are lot of depenedencies necessary for taking
+ * mac address. Instead to making some static dependecies orafce uses
+ * dynamic dependency on "uuid-ossp" extension, and calls choosed function
+ * from this extension.
+ */
+Datum
+orafce_sys_guid(PG_FUNCTION_ARGS)
+{
+	bool		reset_fmgr;
+	Oid			funcoid;
+	pg_uuid_t  *uuid;
+	bytea	   *result;
+
+	funcoid = get_uuid_generate_func_oid(&reset_fmgr);
+
+	if (reset_fmgr)
+		fmgr_info_cxt(funcoid,
+					   &uuid_generate_func_finfo,
+					  TopTransactionContext);
+
+	uuid =  DatumGetUUIDP(FunctionCall0Coll(&uuid_generate_func_finfo,
+										    InvalidOid));
+
+	result = palloc(VARHDRSZ + UUID_LEN);
+	SET_VARSIZE(result, VARHDRSZ + UUID_LEN);
+	memcpy(VARDATA(result), uuid->data, UUID_LEN);
+
+	PG_RETURN_BYTEA_P(result);
+}
