@@ -99,9 +99,8 @@ DECLARE
 	buff	VARCHAR(20);
 	stts	INTEGER;
 BEGIN
-	PERFORM DBMS_OUTPUT.DISABLE();
-	PERFORM DBMS_OUTPUT.ENABLE();
 	PERFORM DBMS_OUTPUT.SERVEROUTPUT ('f');
+	PERFORM DBMS_OUTPUT.ENABLE();
 	PERFORM DBMS_OUTPUT.PUT_LINE ('ORAFCE TEST 1');
 	PERFORM DBMS_OUTPUT.PUT_LINE ('ORAFCE TEST 2');
 	SELECT INTO buff,stts line,status FROM DBMS_OUTPUT.GET_LINE();
@@ -124,9 +123,8 @@ DECLARE
 	buff	VARCHAR(20);
 	stts	INTEGER;
 BEGIN
-	PERFORM DBMS_OUTPUT.DISABLE();
-	PERFORM DBMS_OUTPUT.ENABLE();
 	PERFORM DBMS_OUTPUT.SERVEROUTPUT ('f');
+	PERFORM DBMS_OUTPUT.ENABLE();
 	PERFORM DBMS_OUTPUT.PUT_LINE ('ORAFCE TEST 1');
 	PERFORM DBMS_OUTPUT.PUT_LINE ('ORAFCE TEST 2');
 	SELECT INTO buff,stts line,status FROM DBMS_OUTPUT.GET_LINE();
@@ -154,9 +152,9 @@ DECLARE
 	buff	VARCHAR(20);
 	stts	INTEGER;
 BEGIN
-	PERFORM DBMS_OUTPUT.DISABLE();
-	PERFORM DBMS_OUTPUT.ENABLE();
 	PERFORM DBMS_OUTPUT.SERVEROUTPUT ('f');
+	PERFORM DBMS_OUTPUT.ENABLE();
+
 	PERFORM DBMS_OUTPUT.PUT_LINE ('ORAFCE TEST 1');
 	PERFORM DBMS_OUTPUT.PUT_LINE ('ORAFCE TEST 2');
 	SELECT INTO buff,stts line,status FROM DBMS_OUTPUT.GET_LINE();
@@ -182,9 +180,9 @@ DECLARE
 	buff	VARCHAR(20);
 	stts	INTEGER;
 BEGIN
-	PERFORM DBMS_OUTPUT.DISABLE();
-	PERFORM DBMS_OUTPUT.ENABLE();
 	PERFORM DBMS_OUTPUT.SERVEROUTPUT ('f');
+	PERFORM DBMS_OUTPUT.ENABLE();
+
 	PERFORM DBMS_OUTPUT.PUT_LINE ('ORAFCE TEST 1');
 	PERFORM DBMS_OUTPUT.PUT_LINE ('ORAFCE TEST 2');
 	SELECT INTO buff,stts line,status FROM DBMS_OUTPUT.GET_LINE();
@@ -210,9 +208,8 @@ DECLARE
 	buff	VARCHAR(20);
 	stts	INTEGER;
 BEGIN
-	PERFORM DBMS_OUTPUT.DISABLE();
-	PERFORM DBMS_OUTPUT.ENABLE();
 	PERFORM DBMS_OUTPUT.SERVEROUTPUT ('f');
+	PERFORM DBMS_OUTPUT.ENABLE();
 	PERFORM DBMS_OUTPUT.PUT_LINE ('ORAFCE TEST 1
 ');
 	PERFORM DBMS_OUTPUT.PUT_LINE ('ORAFCE TEST 2');
@@ -237,9 +234,9 @@ DECLARE
 	buff	VARCHAR(20);
 	stts	INTEGER;
 BEGIN
-	PERFORM DBMS_OUTPUT.DISABLE();
-	PERFORM DBMS_OUTPUT.ENABLE();
 	PERFORM DBMS_OUTPUT.SERVEROUTPUT ('f');
+	PERFORM DBMS_OUTPUT.ENABLE();
+
 	PERFORM DBMS_OUTPUT.PUT_LINE ('ORA
 F
 CE');
@@ -264,9 +261,8 @@ DECLARE
 	buff3	VARCHAR(20);
 	stts	INTEGER := 10;
 BEGIN
-	PERFORM DBMS_OUTPUT.DISABLE();
-	PERFORM DBMS_OUTPUT.ENABLE();
 	PERFORM DBMS_OUTPUT.SERVEROUTPUT ('f');
+	PERFORM DBMS_OUTPUT.ENABLE();
 	PERFORM DBMS_OUTPUT.PUT_LINE ('ORAFCE TEST 1');
 	PERFORM DBMS_OUTPUT.PUT_LINE ('ORAFCE TEST 2');
 	PERFORM DBMS_OUTPUT.PUT_LINE ('ORAFCE TEST 3');
@@ -294,9 +290,8 @@ DECLARE
 	buff2	VARCHAR(20);
 	stts	INTEGER := 2;
 BEGIN
-	PERFORM DBMS_OUTPUT.DISABLE();
-	PERFORM DBMS_OUTPUT.ENABLE();
 	PERFORM DBMS_OUTPUT.SERVEROUTPUT ('f');
+	PERFORM DBMS_OUTPUT.ENABLE();
 	PERFORM DBMS_OUTPUT.PUT_LINE ('ORAFCE TEST 1');
 	PERFORM DBMS_OUTPUT.PUT_LINE ('ORAFCE TEST 2');
 	PERFORM DBMS_OUTPUT.PUT_LINE ('ORAFCE TEST 3');
@@ -321,9 +316,8 @@ DECLARE
 	buff	VARCHAR(20);
 	stts	INTEGER := 1;
 BEGIN
-	PERFORM DBMS_OUTPUT.DISABLE();
-	PERFORM DBMS_OUTPUT.ENABLE();
 	PERFORM DBMS_OUTPUT.SERVEROUTPUT ('f');
+	PERFORM DBMS_OUTPUT.ENABLE();
 	PERFORM DBMS_OUTPUT.PUT_LINE ('ORAFCE TEST 1');
 	PERFORM DBMS_OUTPUT.PUT_LINE ('ORAFCE TEST 2');
 	SELECT INTO buff,stts lines[1],numlines FROM DBMS_OUTPUT.GET_LINES(stts);
@@ -349,9 +343,8 @@ DECLARE
 	buff	VARCHAR(20);
 	stts	INTEGER := 1;
 BEGIN
-	PERFORM DBMS_OUTPUT.DISABLE();
-	PERFORM DBMS_OUTPUT.ENABLE();
 	PERFORM DBMS_OUTPUT.SERVEROUTPUT ('f');
+	PERFORM DBMS_OUTPUT.ENABLE();
 	PERFORM DBMS_OUTPUT.PUT_LINE ('ORAFCE TEST 1');
 	PERFORM DBMS_OUTPUT.PUT_LINE ('ORAFCE TEST 2');
 	SELECT INTO buff,stts lines[1],numlines FROM DBMS_OUTPUT.GET_LINES(stts);
@@ -377,9 +370,8 @@ DECLARE
 	buff	VARCHAR(20);
 	stts	INTEGER := 1;
 BEGIN
-	PERFORM DBMS_OUTPUT.DISABLE();
-	PERFORM DBMS_OUTPUT.ENABLE();
 	PERFORM DBMS_OUTPUT.SERVEROUTPUT ('f');
+	PERFORM DBMS_OUTPUT.ENABLE();
 	PERFORM DBMS_OUTPUT.PUT_LINE ('ORAFCE TEST 1');
 	PERFORM DBMS_OUTPUT.PUT_LINE ('ORAFCE TEST 2');
 	SELECT INTO buff,stts lines[1],numlines FROM DBMS_OUTPUT.GET_LINES(stts);
@@ -405,9 +397,8 @@ DECLARE
 	buff	VARCHAR(20);
 	stts	INTEGER := 1;
 BEGIN
-	PERFORM DBMS_OUTPUT.DISABLE();
-	PERFORM DBMS_OUTPUT.ENABLE();
 	PERFORM DBMS_OUTPUT.SERVEROUTPUT ('f');
+	PERFORM DBMS_OUTPUT.ENABLE();
 	PERFORM DBMS_OUTPUT.PUT_LINE ('ORA
 F
 CE');
@@ -430,9 +421,9 @@ DECLARE
 	buff2	VARCHAR(20);
 	stts	INTEGER := 10;
 BEGIN
-	PERFORM DBMS_OUTPUT.DISABLE();
-	PERFORM DBMS_OUTPUT.ENABLE();
 	PERFORM DBMS_OUTPUT.SERVEROUTPUT ('f');
+	PERFORM DBMS_OUTPUT.ENABLE();
+
 	PERFORM DBMS_OUTPUT.PUT ('ORA');
 	PERFORM DBMS_OUTPUT.NEW_LINE();
 	PERFORM DBMS_OUTPUT.PUT ('FCE');
@@ -456,9 +447,8 @@ DECLARE
 	buff1	VARCHAR(3000);
 	stts	INTEGER := 10;
 BEGIN
-	PERFORM DBMS_OUTPUT.DISABLE();
-	PERFORM DBMS_OUTPUT.ENABLE();
 	PERFORM DBMS_OUTPUT.SERVEROUTPUT ('f');
+	PERFORM DBMS_OUTPUT.ENABLE();
 	PERFORM DBMS_OUTPUT.ENABLE(2000);
 	FOR j IN 1..1999 LOOP
 		PERFORM DBMS_OUTPUT.PUT ('A');
@@ -482,9 +472,8 @@ DECLARE
 	buff	VARCHAR(20);
 	stts	INTEGER;
 BEGIN
-	PERFORM DBMS_OUTPUT.DISABLE();
-	PERFORM DBMS_OUTPUT.ENABLE();
 	PERFORM DBMS_OUTPUT.SERVEROUTPUT ('f');
+	PERFORM DBMS_OUTPUT.ENABLE();
 	PERFORM DBMS_OUTPUT.PUT_LINE ('ORAFCE TEST 1');
 	PERFORM DBMS_OUTPUT.DISABLE();
 	PERFORM DBMS_OUTPUT.ENABLE();
@@ -541,9 +530,8 @@ DECLARE
 	buff	VARCHAR(20);
 	stts	INTEGER := 10;
 BEGIN
-	PERFORM DBMS_OUTPUT.DISABLE();
-	PERFORM DBMS_OUTPUT.ENABLE();
 	PERFORM DBMS_OUTPUT.SERVEROUTPUT ('f');
+	PERFORM DBMS_OUTPUT.ENABLE();
 	PERFORM DBMS_OUTPUT.DISABLE();
 	PERFORM DBMS_OUTPUT.PUT_LINE ('ORAFCE TEST 1');
 	SELECT INTO buff,stts lines[1],numlines FROM DBMS_OUTPUT.GET_LINES(stts);
@@ -564,9 +552,9 @@ DECLARE
 	status	INTEGER;
 	num		INTEGER := 2000;
 BEGIN
-	PERFORM DBMS_OUTPUT.DISABLE();
-	PERFORM DBMS_OUTPUT.ENABLE();
 	PERFORM DBMS_OUTPUT.SERVEROUTPUT ('t');
+	PERFORM DBMS_OUTPUT.ENABLE();
+
 	PERFORM DBMS_OUTPUT.ENABLE(2000);
 	PERFORM DBMS_OUTPUT.PUT ('ORAFCE TEST 1');
 	PERFORM DBMS_OUTPUT.NEW_LINE();
@@ -585,9 +573,9 @@ DECLARE
 	buff	VARCHAR(20);
 	stts	INTEGER;
 BEGIN
-	PERFORM DBMS_OUTPUT.DISABLE();
-	PERFORM DBMS_OUTPUT.ENABLE();
 	PERFORM DBMS_OUTPUT.SERVEROUTPUT ('f');
+	PERFORM DBMS_OUTPUT.ENABLE();
+
 	PERFORM DBMS_OUTPUT.DISABLE();
 	PERFORM DBMS_OUTPUT.ENABLE();
 	PERFORM DBMS_OUTPUT.PUT_LINE ('ORAFCE TEST 1');
@@ -612,9 +600,9 @@ DECLARE
 	buff	VARCHAR(20);
 	stts	INTEGER := 10;
 BEGIN
-	PERFORM DBMS_OUTPUT.DISABLE();
-	PERFORM DBMS_OUTPUT.ENABLE();
 	PERFORM DBMS_OUTPUT.SERVEROUTPUT ('f');
+	PERFORM DBMS_OUTPUT.ENABLE();
+
 	PERFORM DBMS_OUTPUT.DISABLE();
 	PERFORM DBMS_OUTPUT.ENABLE();
 	PERFORM DBMS_OUTPUT.PUT_LINE ('ORAFCE TEST 1');
@@ -676,9 +664,9 @@ DECLARE
 	buff	VARCHAR(20);
 	stts	INTEGER;
 BEGIN
-	PERFORM DBMS_OUTPUT.DISABLE();
-	PERFORM DBMS_OUTPUT.ENABLE();
 	PERFORM DBMS_OUTPUT.SERVEROUTPUT ('f');
+	PERFORM DBMS_OUTPUT.ENABLE();
+
 	PERFORM DBMS_OUTPUT.PUT_LINE ('ORAFCE TEST 1');
 	PERFORM DBMS_OUTPUT.ENABLE();
 	SELECT INTO buff,stts line,status FROM DBMS_OUTPUT.GET_LINE();
@@ -762,3 +750,46 @@ END;
 $$ LANGUAGE plpgsql;
 SELECT dbms_output_test();
 DROP FUNCTION dbms_output_test();
+
+-- SERVEROUTPUT [4] SERVEROUTPUT('t') get_line return null
+CREATE TABLE dbms_output_test (buff VARCHAR(20), status INTEGER);
+CREATE FUNCTION dbms_output_test() RETURNS VOID AS $$
+DECLARE
+	buff	VARCHAR(20);
+	stts	INTEGER;
+BEGIN
+	PERFORM DBMS_OUTPUT.SERVEROUTPUT ('t');
+	PERFORM DBMS_OUTPUT.ENABLE();
+	PERFORM DBMS_OUTPUT.PUT_LINE ('ORAFCE TEST 1');
+	PERFORM DBMS_OUTPUT.PUT_LINE ('ORAFCE TEST 2');
+	SELECT INTO buff,stts line,status FROM DBMS_OUTPUT.GET_LINE();
+	INSERT INTO dbms_output_test VALUES (buff, stts);
+	SELECT INTO buff,stts line,status FROM DBMS_OUTPUT.GET_LINE();
+	INSERT INTO dbms_output_test VALUES (buff, stts);
+	PERFORM DBMS_OUTPUT.DISABLE();
+	PERFORM DBMS_OUTPUT.ENABLE();
+END;
+$$ LANGUAGE plpgsql;
+SELECT dbms_output_test();
+SELECT * FROM dbms_output_test;
+DROP TABLE dbms_output_test;
+DROP FUNCTION dbms_output_test();
+
+-- test dbms_output.serveroutput(false) clear buffer
+select dbms_output.serveroutput(true);
+do $$
+BEGIN
+	PERFORM DBMS_OUTPUT.PUT_LINE('1234242');
+END$$;
+
+select dbms_output.serveroutput(false);
+do $$
+BEGIN
+	PERFORM DBMS_OUTPUT.PUT_LINE('1234242');
+END$$;
+
+select dbms_output.serveroutput(true);
+do $$
+BEGIN
+	PERFORM DBMS_OUTPUT.PUT_LINE('1234242');
+END$$;
