@@ -107,6 +107,71 @@ $$;
 select * from foo;
 truncate foo;
 
+-- should not to crash, when bound array is null
+do $$
+declare
+  c int;
+  ca numeric[];
+begin
+  c := dbms_sql.open_cursor();
+  call dbms_sql.parse(c, 'insert into foo values(:a, 10, 20)');
+
+  call dbms_sql.bind_array(c, 'a', ca);
+  raise notice 'inserted rows %d', dbms_sql.execute(c);
+end;
+$$;
+
+-- should not to crash, when we try to touch result without execute
+do $$
+declare
+  c int;
+  a int[];
+begin
+  c := dbms_sql.open_cursor();
+  call dbms_sql.parse(c, 'select i from generate_series(1, 2) g(i)');
+  call dbms_sql.define_array(c, 1, a, 10, 1);
+  call dbms_sql.column_value(c, 1, a);
+  call dbms_sql.close_cursor(c);
+end;
+$$;
+
+-- should not to crash, when the variable is overwritten
+DO $$
+declare
+  c integer;
+  n integer;
+  c2 numeric;
+begin
+  c := dbms_sql.open_cursor();
+  call dbms_sql.parse(c, 'INSERT INTO foo(a) VALUES (:bnd2)');
+  call dbms_sql.bind_variable(c, 'bnd2', c2);
+  call dbms_sql.bind_variable(c, 'bnd2', c2);
+  n := dbms_sql.execute(c);
+end
+$$;
+
+-- should not to crash, when we try to read column without data
+do $$
+declare
+  c int;
+  strval varchar;
+  intval int;
+begin
+  c := dbms_sql.open_cursor();
+  call dbms_sql.parse(c, 'select ''foo'', 1');
+  call dbms_sql.define_column(c, 1, strval);
+  call dbms_sql.define_column(c, 2, intval);
+  perform dbms_sql.execute(c);
+  while dbms_sql.fetch_rows(c) > -1
+  loop
+    call dbms_sql.column_value(c, 1, strval);
+  end loop;
+  call dbms_sql.close_cursor(c);
+end;
+$$;
+
+select * from foo;
+truncate foo;
 do $$
 declare
   c int;
