@@ -236,7 +236,19 @@ select oracle.substr('TechOnTheNet', 1, 4) =  'Tech';
 select oracle.substr('TechOnTheNet', -3, 3) =  'Net';
 select oracle.substr('TechOnTheNet', -6, 3) =  'The';
 select oracle.substr('TechOnTheNet', -8, 2) =  'On';
+
+set orafce.using_substring_zero_width_in_substr TO orafce;
 select oracle.substr('TechOnTheNet', -8, 0) =  '';
+
+set orafce.using_substring_zero_width_in_substr TO oracle;
+select oracle.substr('TechOnTheNet', -8, 0) is null;
+
+set orafce.using_substring_zero_width_in_substr TO warning_oracle;
+select oracle.substr('TechOnTheNet', -8, 0) is null;
+
+set orafce.using_substring_zero_width_in_substr TO default;
+select oracle.substr('TechOnTheNet', -8, 0) is null;
+
 select oracle.substr('TechOnTheNet', -8, -1) =  '';
 select oracle.substr(1234567,3.6::smallint)='4567';
 select oracle.substr(1234567,3.6::int)='4567';
@@ -498,6 +510,17 @@ select to_char(1234567890.12345);
 select to_char('4.00'::numeric);
 select to_char('4.0010'::numeric);
 
+select to_char('-44444');
+select to_char('1234567890123456');
+select to_char('123.456');
+select to_char('123abc');
+select to_char('你好123@$%abc');
+select to_char('1234567890123456789012345678901234567890123456789012345678901234567890');
+select to_char('');
+select to_char(' ');
+select to_char(null);
+
+
 SELECT to_number('123'::text);
 SELECT to_number('123.456'::text);
 SELECT to_number(123);
